@@ -151,46 +151,38 @@ class DetectionListUserClient(BaseClient):
         uri = self._make_uri(u"/removeriskfactors")
         return self._session.post(uri, data=json.dumps(data))
 
-    def add_cloud_aliases(self, user_id, aliases):
-        """Add one or more cloud alias.
+    def add_cloud_alias(self, user_id, alias):
+        """Add a cloud alias.
 
         Args:
-            user_id (str or int): The user_id whose alias(es) need to be updated.
-            aliases (str or list of str ): A single alias or multiple aliases in a list to be added.
-                e.g u"x" or ["email@id", "y"], for python version 2.X, pass u"str" instead of "str"
+            user_id (str or int): The user_id whose alias needs to be updated.
+            alias (str): An alias to be added.
 
         Returns:
             :class:`py42.response.Py42Response`
         """
-        if type(aliases) is str:
-            aliases = [aliases]
-
         data = {
             u"tenantId": self._user_context.get_current_tenant_id(),
             u"userId": user_id,
-            u"cloudUsernames": aliases,
+            u"cloudUsernames": [alias],
         }
         uri = self._make_uri(u"/addcloudusernames")
         return self._session.post(uri, data=json.dumps(data))
 
-    def remove_cloud_aliases(self, user_id, aliases):
+    def remove_cloud_alias(self, user_id, alias):
         """Remove one or more cloud alias.
 
         Args:
-            user_id (str or int): The user_id whose alias(es) need to be removed.
-            aliases (str or list of str ): A single alias or multiple aliases in a list to be removed.
-                e.g u"x" or ["email@id", "y"], for python version 2.X, pass u"str" instead of "str"
+            user_id (str or int): The user_id whose alias needs to be removed.
+            alias (str): An alias to be removed.
 
         Returns:
             :class:`py42.response.Py42Response`
         """
-        if type(aliases) is str:
-            aliases = [aliases]
-
         data = {
             u"tenantId": self._user_context.get_current_tenant_id(),
             u"userId": user_id,
-            u"cloudUsernames": aliases,
+            u"cloudUsernames": [alias],
         }
         uri = self._make_uri(u"/removecloudusernames")
         return self._session.post(uri, data=json.dumps(data))
